@@ -31,6 +31,9 @@ def standard_config(n_cpus=1):
 
     CONFIG["final_statistics.lambda"] = lambda_
 
+    CONFIG["final_statistics.fdr_all_pg"] = False
+    info["final_statistics.fdr_all_pg"] = """[use all peak groups for score & q-value calculation]"""
+
     CONFIG["num_processes"] = n_cpus
     info["num_processes"] = "[-1 means 'all available cpus']"
 
@@ -45,10 +48,13 @@ def standard_config(n_cpus=1):
 
     CONFIG["ignore.invalid_score_columns"] = False
     info["ignore.invalid_score_columns"] =\
-        """ignore score columns which only contain NaN of infinity values"""
+        """[ignore score columns which only contain NaN or infinity values]"""
 
-    CONFIG["apply"] = None
-    info["apply"] = r"""[name of *_scorer.bin file of existing classifier]"""
+    CONFIG["apply_scorer"] = None
+    info["apply_scorer"] = r"""[name of *_scorer.bin file of existing classifier]"""
+
+    CONFIG["apply_weights"] = None
+    info["apply_weights"] = r"""[name of *_weights.txt file of existing LDA weights]"""
 
     CONFIG["export.mayu"] = False
     info["export.mayu"] = """[export input files for MAYU]"""
@@ -56,6 +62,9 @@ def standard_config(n_cpus=1):
     CONFIG["compute.probabilities"] = False
     info["compute.probabilities"] = """[Compute approximate binned probability values]"""
 
+    CONFIG["d_score.cutoff"] = -1000.0
+    info["d_score.cutoff"] = """[Filter output such that only results with a d_score higher than this value are reported]"""
+
     return CONFIG, info
 
 CONFIG, __ = standard_config()
@@ -71,6 +80,7 @@ def fix_config_types(dd):
         dd[k] = int(dd[k])
 
     for k in ["xeval.fraction",
+              "d_score.cutoff",
               "semi_supervised_learner.initial_fdr",
               "semi_supervised_learner.initial_lambda",
               "semi_supervised_learner.iteration_lambda",
